-- $Id: pgsql_geoip2_tables.sql 683 2018-11-04 19:24:33Z bhockney $
--
-- Schema for geoip version 2 tables. After creating the blocks and locations
-- tables, download the CVS files from maxmind at:
-- http://dev.maxmind.com/geoip/geoip2/geolite2/
-- Unzip the archive, then use the postgresql COPY command to load the tables.
-- You must load at least the Blocks-IPv4.csv or Blocks-IPv6.csv (or both), and
-- also load the the Locations-xx.csv file, where xx is your preferred locale.
-- You may load multiple locations files for different locales if you wish.
--

-- the ip4r extension needs to be installed first
-- CREATE EXTENSION IF NOT EXISTS ip4r;

-- Create blocks table
CREATE TABLE "blocks" (
  "network"                        cidr             NOT NULL,
  "geoname_id"                     integer          DEFAULT NULL,
  "registered_country_geoname_id"  integer          DEFAULT NULL,
  "represented_country_geoname_id" integer          DEFAULT NULL,
  "is_anonymous_proxy"             boolean          NOT NULL,
  "is_satellite_provider"          boolean          NOT NULL,
  "postal_code"                    text             DEFAULT NULL,
  "latitude"                       double precision DEFAULT NULL,
  "longitude"                      double precision DEFAULT NULL,
  "accuracy_radius"                integer          DEFAULT NULL,
  PRIMARY KEY  (network)
);
-- Always create the gist index on network and also indices on geoname_id columns,
-- used for joining locations table.
CREATE INDEX "blocks_ip4r_network"            ON "blocks" USING gist (iprange(network));
CREATE INDEX "geoname_id"                     ON "blocks" (geoname_id);
CREATE INDEX "registered_country_geoname_id"  ON "blocks" (registered_country_geoname_id);
CREATE INDEX "represented_country_geoname_id" ON "blocks" (represented_country_geoname_id);
-- Create indices below on columns frequently referenced in queries to improve performance.
-- You can create as many or few as you need.
-- CREATE INDEX "postal_code"                    ON "blocks" (postal_code);
-- CREATE INDEX "latitude"                       ON "blocks" (latitude);
-- CREATE INDEX "longitude"                      ON "blocks" (longitude);
-- CREATE INDEX "accuracy_radius"                ON "blocks" (accuracy_radius);

-- Create locations table
CREATE TABLE "locations" (
  "geoname_id"             integer NOT NULL,
  "locale_code"            text    NOT NULL,
  "continent_code"         text    DEFAULT NULL,
  "continent_name"         text    DEFAULT NULL,
  "country_iso_code"       text    DEFAULT NULL,
  "country_name"           text    DEFAULT NULL,
  "subdivision_1_iso_code" text    DEFAULT NULL,
  "subdivision_1_name"     text    DEFAULT NULL,
  "subdivision_2_iso_code" text    DEFAULT NULL,
  "subdivision_2_name"     text    DEFAULT NULL,
  "city_name"              text    DEFAULT NULL,
  "metro_code"             integer DEFAULT NULL,
  "time_zone"              text    DEFAULT NULL,
  PRIMARY KEY (geoname_id, locale_code)
);
-- Create indices below on columns frequently referenced in queries to improve performance.
-- You can create as many or few as you need.
-- CREATE INDEX "continent_code"         ON "locations" (continent_code);
-- CREATE INDEX "continent_name"         ON "locations" (continent_name);
-- CREATE INDEX "country_iso_code"       ON "locations" (country_iso_code);
-- CREATE INDEX "country_name"           ON "locations" (country_name);
-- CREATE INDEX "subdivision_1_iso_code" ON "locations" (subdivision_1_iso_code);
-- CREATE INDEX "subdivision_1_name"     ON "locations" (subdivision_1_name);
-- CREATE INDEX "subdivision_2_iso_code" ON "locations" (subdivision_2_iso_code);
-- CREATE INDEX "subdivision_2_name"     ON "locations" (subdivision_2_name);
-- CREATE INDEX "city_name"              ON "locations" (city_name);
-- CREATE INDEX "metro_code"             ON "locations" (metro_code);
-- CREATE INDEX "time_zone"              ON "locations" (time_zone);

-- vim: set syntax=sql:
