<?php
/*
$Id: functions_geoip.php 684 2018-11-07 19:26:36Z bhockney $
(C) 2003-2018 by Bob Hockney <zeus@ix.netcom.com>

geoip functions for webfwlog

This code is distributed under the terms of GNU GPL
*/
?>
<?php

// creates new reader class
function geoip2_open (&$config) {
	$reader = false;
	try {
		$reader = new MaxMind\Db\Reader($config["geoip2_file"]);
		$config["have_geoip2_db"] = true;
	} catch (Exception $e) {
		if ($config["debug"] == 1)
			print "\n<!-- {$e->getMessage()} -->\n";
		if ($config["debug"] == 2)
			print "\n{$e->getMessage()}\n";
		$config["have_geoip2_db"] = false;
	}
	return $reader;
}

// Return geoip2 value if using local lookup. Not called otherwise.
function geoip2_lookup ($colkey, $value, &$line, &$reader) {
	global $config, $version_php, $geoip_columns, $source, $shortnames, $php_inet_ntop;

	$ret = $value;
	$c = preg_split('/(_s|_d)$/', $colkey,NULL,PREG_SPLIT_DELIM_CAPTURE);
	try {
		$ip = "";
		if ($source == "syslog" or (isset($config["packet_page"]))) {
			if(isset($line["ip{$c[1]}addr{$config["addr_type"]}"])) {
				if($config["iptype"] == "bin") {
					$ip = $php_inet_ntop($line["ip{$c[1]}addr{$config["addr_type"]}"]); 
				} else {
					$ip = $line["ip{$c[1]}addr{$config["addr_type"]}"];
				}
			}
		} else { 
			if(isset($line["{$shortnames["ip{$c[1]}addr"]}"]))
				$ip = $line["{$shortnames["ip{$c[1]}addr"]}"];
		}
		$r = $reader->get($ip);
		switch ($c[0]) {
			case "continent_code":
				if(isset($r["continent"]["code"]))
					$ret = $r["continent"]["code"];
				break;
			case "continent_name":
				if(isset($r["continent"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["continent"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "country_iso_code":
				if(isset($r["country"]["iso_code"]))
					$ret = $r["country"]["iso_code"];
				break;
			case "country_name":
				if(isset($r["country"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["country"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "subdivision_1_iso_code":
				if(isset($r["subdivisions"]["0"]["iso_code"]))
					$ret = $r["subdivisions"]["0"]["iso_code"];
				break;
			case "subdivision_1_name":
				if(isset($r["subdivisions"]["0"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["subdivisions"]["0"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "subdivision_2_iso_code":
				if(isset($r["subdivisions"]["1"]["iso_code"]))
					$ret = $r["subdivisions"]["1"]["iso_code"];
				break;
			case "subdivision_2_name":
				if(isset($r["subdivisions"]["1"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["subdivisions"]["1"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "city_name":
				if(isset($r["city"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["city"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "metro_code":
				if(isset($r["location"]["metro_code"]))
					$ret = $r["location"]["metro_code"];
				break;
			case "time_zone":
				if(isset($r["location"]["time_zone"]))
					$ret = $r["location"]["time_zone"];
				break;
			case "accuracy_radius":
				if(isset($r["location"]["accuracy_radius"]))
					$ret = $r["location"]["accuracy_radius"];
				break;
			case "registered_country_geoname_id":
				if(isset($r["registered_country"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["registered_country"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "represented_country_geoname_id":
				if(isset($r["represented_country"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["represented_country"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "is_anonymous_proxy":
				if(isset($r["traits"]["is_anonymous_proxy"]))
					$ret = $r["traits"]["is_anonymous_proxy"];
				break;
			case "is_satellite_provider":
				if(isset($r["traits"]["is_satellite_provider"]))
					$ret = $r["traits"]["is_satellite_provider"];
				break;
			case "postal_code":
				if(isset($r["postal"]["code"]))
					$ret = $r["postal"]["code"];
				break;
			case "latitude":
				if(isset($r["location"]["latitude"]))
					$ret = $r["location"]["latitude"];
				break;
			case "longitude":
				if(isset($r["location"]["longitude"]))
					$ret = $r["location"]["longitude"];
				break;
			default:
				break;
		}
	} catch (Exception $e) {
		print $e->getMessage();
	}
	return $ret;
}

// vim:set ts=4: 
?>
